/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright 2020-2025 The JReleaser authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jreleaser.sdk.linkedin.api;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

/**
 * @author Andres Almiray
 * @since 1.5.0
 */
@JsonIgnoreProperties(ignoreUnknown = true)
public class Message {
    private String owner;
    private String subject;
    private Text text;
    private Distribution distribution = new Distribution();

    public String getOwner() {
        return owner;
    }

    public void setOwner(String owner) {
        this.owner = owner;
    }

    public String getSubject() {
        return subject;
    }

    public void setSubject(String subject) {
        this.subject = subject;
    }

    public Text getText() {
        return text;
    }

    public void setText(Text text) {
        this.text = text;
    }

    public Distribution getDistribution() {
        return distribution;
    }

    public void setDistribution(Distribution distribution) {
        this.distribution = distribution;
    }

    public static Message of(String subject, String text) {
        Message message = new Message();
        message.subject = subject;
        message.text = new Text(text);
        return message;
    }

    public static final class Text {
        private String text;

        public Text(String text) {
            this.text = text;
        }

        public String getText() {
            return text;
        }

        public void setText(String text) {
            this.text = text;
        }
    }

    public static final class Distribution {
        private Target linkedInDistributionTarget = new Target();

        public Target getLinkedInDistributionTarget() {
            return linkedInDistributionTarget;
        }

        public void setLinkedInDistributionTarget(Target linkedInDistributionTarget) {
            this.linkedInDistributionTarget = linkedInDistributionTarget;
        }

        @JsonIgnoreProperties(ignoreUnknown = true)
        public static final class Target {

        }
    }
}
